QscanT.Auth (QscanT v0.1.1) View Source

Qscan Commands that do not require password authentication to use. Verbage and reference from the Qscan tcpx4.pdf reference. Reference revision date March 7, 2011

Link to this section Summary

Functions

Request the reader's current IP Address, MAC address, and Reader ID seperated by a : Example format for a return sequence 192.168.1.55:aabbccddeeff:ibc reader

Send the password to the reader to allow for all other control commands reader returns back an "OK" in response if password is valid. Password MUST be 5 characters long, or blank filled to be valid Default password is "11111"

Link to this section Functions

Link to this function

identify()

View Source (since 0.1.0)

Request the reader's current IP Address, MAC address, and Reader ID seperated by a : Example format for a return sequence 192.168.1.55:aabbccddeeff:ibc reader

Link to this function

password(pass)

View Source (since 0.1.0)

Send the password to the reader to allow for all other control commands reader returns back an "OK" in response if password is valid. Password MUST be 5 characters long, or blank filled to be valid Default password is "11111"