QscanT.Symbology (QscanT v0.1.1) View Source

Qscan symbology commands. Verbage and reference from the qscan203 reference Reference revision date February 26, 2019

Link to this section Summary

Functions

Generates a string of 7 symbology setup commands to cover all symbologies. This will enable only symbologies defined in the input map symbols, and will deactivate all other symbologies from the reader

Link to this section Functions

Link to this function

symbology_setup(symbols)

View Source (since 0.1.0)

Generates a string of 7 symbology setup commands to cover all symbologies. This will enable only symbologies defined in the input map symbols, and will deactivate all other symbologies from the reader

Returns tuple {:ok, bin} where bin is defined as the resultant commands

Examples

iex> QscanT.Symbology.symbology_setup(%{code_39: true, qr: true})
{:ok,
"X00110000000

X00200000000 X00300000000 X00400000000 X00500000000 X00600010000 X00700000000 "}

Link to this function

symbology_setup1(symbols)

Link to this function

symbology_setup2(symbols)

Link to this function

symbology_setup3(symbols)

Link to this function

symbology_setup4(symbols)

Link to this function

symbology_setup5(symbols)

Link to this function

symbology_setup6(symbols)

Link to this function

symbology_setup7(symbols)

View Source