QscanT.Commands (QscanT v0.1.1) View Source
Qscan Commands. Verbage and reference from the qscan203.pdf reference. Reference revision date February 26, 2019
Link to this section Summary
Functions
Set control card mode. If set true, control cards cannot be scanned to program the device. When locked, can only be controlled via serial data channel
Generates a binary with the given parameter string, and an array of values.
Restarts the QScan Device
Command to return the firmware identification string
Link to this section Functions
Set control card mode. If set true, control cards cannot be scanned to program the device. When locked, can only be controlled via serial data channel
Generates a binary with the given parameter string, and an array of values.
Returns tuple {:ok, bin} where bin is defined as the parameter string,
the values passed in order, and a carraige return (
)
Examples
iex> QscanT.Commands.encode("X092", ["y"])
{:ok, "X092y"}
Restarts the QScan Device
Command to return the firmware identification string