QscanT.Peripherals (QscanT v0.1.1) View Source
Qscan Peripheral Commands. Verbage from the qscan203.pdf reference. Reference revision date February 26, 2019
Link to this section Summary
Functions
Blinks the bicolor led for time seconds, then leaves it in the "off" state
Blinks the bicolor led for time seconds, then leaves it in the "on" state
Turns the bicolor led off for time seconds, then leaves it in the "on" state
Turns the bicolor led on for time seconds, then leaves it in the "off" state
Sets the bicolor led's mode between it's three options: "off" | "on" ------+------- red | green off | red off | green
Blinks thee green led for time seconds, then leaves it off
Blinks the green led for time seconds, then leaves it on
Turns the green led off for time seconds, then leaves it off
Turns the green led on for time seconds, then leaves it off
Poll digital input 1, device will respond with "ON" or "OFF"
Poll digital input 2, device will respond with "ON" or "OFF"
Turn the relay off
Turn the relay on for time seconds (up to 99)
Configure automatic sense events on digital inputs. Device is capable of both rising and falling edge sensing. There is a 3/10ths a second delay between event and sense trigger. This function generates the masking command for these events
Turn the speaker on for time * 10ms duration
Actual speaker frequency / duty cycle is defined in speaker_setup
Setup the speaker for output good_read_beep_time is expressed in intervals of 40ms
Link to this section Functions
Blinks the bicolor led for time seconds, then leaves it in the "off" state
Blinks the bicolor led for time seconds, then leaves it in the "on" state
Turns the bicolor led off for time seconds, then leaves it in the "on" state
Turns the bicolor led on for time seconds, then leaves it in the "off" state
Sets the bicolor led's mode between it's three options: "off" | "on" ------+------- red | green off | red off | green
Blinks thee green led for time seconds, then leaves it off
Blinks the green led for time seconds, then leaves it on
Turns the green led off for time seconds, then leaves it off
Turns the green led on for time seconds, then leaves it off
Poll digital input 1, device will respond with "ON" or "OFF"
Poll digital input 2, device will respond with "ON" or "OFF"
Turn the relay off
Turn the relay on for time seconds (up to 99)
set_digital_event_mask(digital_1_rising?, digital_1_falling?, digital_2_rising?, digital_2_falling?)
View SourceConfigure automatic sense events on digital inputs. Device is capable of both rising and falling edge sensing. There is a 3/10ths a second delay between event and sense trigger. This function generates the masking command for these events
Turn the speaker on for time * 10ms duration
Actual speaker frequency / duty cycle is defined in speaker_setup
speaker_setup(startup_beep?, frequency, duty_on, duty_off, good_read_beep_time)
View Source (since 0.1.0)Setup the speaker for output good_read_beep_time is expressed in intervals of 40ms