QscanT.Symbology (QscanT v0.1.1) View Source
Qscan symbology commands. Verbage and reference from the qscan203 reference Reference revision date February 26, 2019
Link to this section Summary
Functions
Generates a string of 7 symbology setup commands to cover all symbologies. This will enable only symbologies defined in the input map symbols, and will deactivate all other symbologies from the reader
Link to this section Functions
Generates a string of 7 symbology setup commands to cover all symbologies. This will enable only symbologies defined in the input map symbols, and will deactivate all other symbologies from the reader
Returns tuple {:ok, bin} where bin is defined as the resultant commands
Examples
iex> QscanT.Symbology.symbology_setup(%{code_39: true, qr: true})
{:ok,
"X00110000000X00200000000 X00300000000 X00400000000 X00500000000 X00600010000 X00700000000 "}